# Generated by Django 3.2.15 on 2022-08-13 17:14

from django.db import migrations, models

import django_rrweb.models


class Migration(migrations.Migration):

    dependencies = [
        ('django_rrweb', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='session',
            name='key',
            field=models.CharField(
                default=django_rrweb.models._make_key,
                max_length=100,
                unique=True,
            ),
        ),
    ]
