# Generated by Django 3.2.15 on 2022-08-18 04:57

import django.db.models.deletion
from django.db import migrations, models

import django_rrweb.models


class Migration(migrations.Migration):

    dependencies = [
        ('django_rrweb', '0002_session_key'),
    ]

    operations = [
        migrations.CreateModel(
            name='Page',
            fields=[
                (
                    'id',
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name='ID',
                    ),
                ),
                ('create_time', models.DateTimeField(auto_now_add=True)),
                (
                    'key',
                    models.CharField(
                        default=django_rrweb.models._make_key,
                        max_length=100,
                        unique=True,
                    ),
                ),
                (
                    'session',
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name='pages',
                        to='django_rrweb.session',
                    ),
                ),
            ],
        ),
        migrations.AddField(
            model_name='event',
            name='page',
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name='events',
                to='django_rrweb.page',
            ),
        ),
    ]
