# Generated by Django 3.2.15 on 2022-08-18 23:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_rrweb', '0004_auto_20220818_0457'),
    ]

    operations = [
        migrations.AddField(
            model_name='page',
            name='notes',
            field=models.TextField(blank=True, default=''),
        ),
        migrations.AddField(
            model_name='session',
            name='notes',
            field=models.TextField(blank=True, default=''),
        ),
    ]
